@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
-/* SPDX-FileCopyrightText: Marek Lindner <mareklindner@neomailbox.ch>
+/* SPDX-FileCopyrightText: Marek Lindner <marek.lindner@mailbox.org>
  * SPDX-FileCopyrightText: Sven Eckelmann <sven@narfation.org>
  */
 
@@ -131,6 +131,7 @@ void tftp_client_flash_time_set(struct node *node)
 		   (node->router_type == &pa2200.router_type) ||
 		   (node->router_type == &pax1800.router_type) ||
 		   (node->router_type == &pax1800v2.router_type) ||
+		   (node->router_type == &pax5400.router_type) ||
 		   (node->router_type == &tw420.router_type) ||
 		   (node->router_type == &zyxel.router_type)) {
 
@@ -170,6 +171,7 @@ int tftp_client_flash_completed(struct node *node)
 		   (node->router_type == &pa2200.router_type) ||
 		   (node->router_type == &pax1800.router_type) ||
 		   (node->router_type == &pax1800v2.router_type) ||
+		   (node->router_type == &pax5400.router_type) ||
 		   (node->router_type == &tw420.router_type) ||
 		   (node->router_type == &zyxel.router_type)) {
 
@@ -698,6 +700,27 @@ const struct router_tftp_client pax1800v2 = {
 	.ip = OM2P_IP,
 };
 
+static const struct mac_accept_entry pax5400_mac_accept[] = {
+	{
+		.mac = {'P', 'A', 'X', '5', '4', '0'},
+		.mask = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff},
+	},
+};
+
+const struct router_tftp_client pax5400 = {
+	.router_type = {
+		.desc = "PAX5400",
+		.detect_pre = NULL,
+		.detect_main = tftp_client_detect_main,
+		.detect_post = tftp_client_detect_post,
+		.image = &img_ce,
+		.priv_size = sizeof(struct om2p_priv),
+	},
+	.mac_accept_entries = pax5400_mac_accept,
+	.mac_accept_entries_num = ARRAY_SIZE(pax5400_mac_accept),
+	.ip = OM2P_IP,
+};
+
 static const struct mac_accept_entry zyxel_mac_accept[] = {
 	{
 		.mac = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
